@@ -8,4 +8,6 @@ from lightly.data.collate import BaseCollateFunction
 from lightly.data.collate import ImageCollateFunction
 from lightly.data.collate import SimCLRCollateFunction
 from lightly.data.collate import MoCoCollateFunction
+from lightly.data.collate import MultiCropCollateFunction
+from lightly.data.collate import SwaVCollateFunction
 from lightly.data.collate import imagenet_normalize
\ No newline at end of file
