@@ -4,4 +4,6 @@
 # All Rights Reserved
 
 from lightly.loss.ntx_ent_loss import NTXentLoss
-from lightly.loss.sym_neg_cos_sim_loss import SymNegCosineSimilarityLoss
\ No newline at end of file
+from lightly.loss.sym_neg_cos_sim_loss import SymNegCosineSimilarityLoss
+from lightly.loss.barlow_twins_loss import BarlowTwinsLoss
+from lightly.loss.swav_loss import SwaVLoss
