@@ -10,13 +10,20 @@ from torchvision.transforms import functional as TF
 class RandomRotate(object):
     """Implementation of random rotation.
 
-    Randomly rotates an input image by an angle.
+    Randomly rotates an input image by a fixed angle. By default, we rotate
+    the image by 90 degrees with a probability of 50%.
+
+    This augmentation can be very useful for rotation invariant images such as
+    in medical imaging or satellite imaginary.
 
     Attributes:
         prob:
             Probability with which image is rotated.
         angle:
-            Angle by which the image is rotated.
+            Angle by which the image is rotated. We recommend multiples of 90
+            to prevent rasterization artifacts. If you pick numbers like
+            90, 180, 270 the tensor will be rotated without introducing 
+            any artifacts.
     
     """
 
